@@ -26,10 +26,9 @@ from core import gs
 
 if gs.GUIString == "GTK":
     import gobject
-else:
+elif gs.GUIString.lower() == "qml":
     from PySide import QtCore
 
-
 def getModule(m, d, i):
     """
     return module version corresponding to the currently used toolkit
@@ -38,30 +37,31 @@ def getModule(m, d, i):
     """
     if gs.GUIString == 'QML':
         return CronQt(m, d, i)
-    else: # GTK for now
+    elif gs.GUIString == 'GTK': # GTK for now
         return CronGTK(m, d, i)
+    else:
+        return Cron(m, d, i)
 
 
 class Cron(RanaModule):
-    """A timing and scheduling module for modRana
+    """A timing and scheduling module for modRana"""
 
-    -> this is an abstract class
-    that specifies and interface for concrete implementations
-
-    Why is there a special module for timing ?
-       The reason is twofold:
-       Toolkit independence and power saving/monitoring.
-
-       If all timing calls go through this module,
-       the underlying engine (currently glibs gobject)
-       can be more easily changed than rewriting code everywhere.
-
-       Also, modRana targets mobile devices with limited power budget.
-       If all timing goes through this module, rogue modules many frequent
-       timers can be easily identified.
-       It might be also possible to stop or pause some/all of the timers
-       after a period of inactivity, or some such.
-    """
+    # -> this is an abstract class
+    # that specifies and interface for concrete implementations
+    #
+    # Why is there a special module for timing ?
+    #    The reason is twofold:
+    #    Toolkit independence and power saving/monitoring.
+    #
+    #    If all timing calls go through this module,
+    #    the underlying engine (currently glibs gobject)
+    #    can be more easily changed than rewriting code everywhere.
+    #
+    #    Also, modRana targets mobile devices with limited power budget.
+    #    If all timing goes through this module, rogue modules many frequent
+    #    timers can be easily identified.
+    #    It might be also possible to stop or pause some/all of the timers
+    #    after a period of inactivity, or some such.
 
     def __init__(self, m, d, i):
         RanaModule.__init__(self, m, d, i)
@@ -145,7 +145,7 @@ class CronGTK(Cron):
                 del self.cronTab['timeout'][timeoutId]
                 gobject.source_remove(realId)
             else:
-                print("cron: can't remove timeout, wrong id: ", timeoutId)
+                self.log.error("can't remove timeout, wrong id: %s", timeoutId)
 
     def modifyTimeout(self, timeoutId, newTimeout):
         """modify the duration of a timeout in progress"""
@@ -158,7 +158,7 @@ class CronGTK(Cron):
                 # update the timeout description
                 self.cronTab['timeout'][timeoutId] = (callback, args, newTimeout, caller, description, realId)
             else:
-                print("cron: can't modify timeout, wrong id: ", timeoutId)
+                self.log.error("can't modify timeout, wrong id: %s", timeoutId)
 
 
 class CronQt(Cron):
@@ -216,7 +216,7 @@ class CronQt(Cron):
                 timer.stop()
                 del self.cronTab['timeout'][timeoutId]
             else:
-                print("cron: can't remove timeout, wrong id: ", timeoutId)
+                self.log.error("can't remove timeout, wrong id: %s", timeoutId)
 
     def modifyTimeout(self, timeoutId, newTimeout):
         """modify the duration of a timeout in progress"""
@@ -229,7 +229,7 @@ class CronQt(Cron):
                 # update the timeout data
                 self.cronTab['timeout'][timeoutId] = (callback, args, newTimeout, caller, description, timeoutId, timer)
             else:
-                print("cron: can't modify timeout, wrong id: ", timeoutId)
+                self.log.error("can't modify timeout, wrong id: %s", timeoutId)
 
 #  def _addInfo(self, id, info):
 #    """add a message for a timeout handler to read"""
